package com.datacloudsec.scan.service.impl;

import com.datacloudsec.exception.UEException;
import com.datacloudsec.scan.cache.PoliciesSingleton;
import com.datacloudsec.scan.dao.WebTempMapper;
import com.datacloudsec.scan.entity.User;
import com.datacloudsec.scan.service.IWebTemp;
import com.datacloudsec.utils.DataRule;
import com.datacloudsec.utils.InstanceUtil;
import com.datacloudsec.utils.ObjectUtil;
import java.io.File;
import java.util.Arrays;
import java.util.List;
import java.util.Map;
import javax.servlet.http.HttpSession;
import org.apache.commons.io.FileUtils;
import org.apache.commons.lang.StringUtils;
import sun.misc.BASE64Encoder;

/* loaded from: com_datacloudsec_scan_service_impl.jar:com/datacloudsec/scan/service/impl/WebTempService.class */
public class WebTempService implements IWebTemp {
    private WebTempMapper webTempMapper = (WebTempMapper) InstanceUtil.newDaoInstance(WebTempMapper.class);

    public int searchCount(HttpSession session, String name, Integer id) throws Exception {
        return this.webTempMapper.searchCount(name, DataRule.getRuleWhere(session, "t_web_policies"), id);
    }

    public List<Map<String, Object>> search(HttpSession session, String name, Integer offset, Integer limit, Integer id) throws Exception {
        return this.webTempMapper.search(name, offset, limit, id, DataRule.getRuleWhere(session, "t_web_policies"));
    }

    public void delete(HttpSession session, Integer id, Integer version) throws Exception {
        Integer count = this.webTempMapper.getCountWebByTid(id);
        if (count != null && count.intValue() > 0) {
            throw new UEException("当前模板已被网站安全监控任务引用，请在网站安全监控中移除引用关系！");
        }
        Integer vcount = Integer.valueOf(this.webTempMapper.delete(id, version, DataRule.getRuleWhere(session, "t_web_policies")));
        if (vcount.intValue() == 0) {
            throw new UEException("数据已被修改或删除，请刷新页面或返回");
        }
    }

    public void insert(HttpSession session, String name, String name_en, String name_zh) throws Exception {
        Integer uid = ((User) session.getAttribute("userInfo")).getId();
        Integer count = this.webTempMapper.getCountByName(name, (Integer) null, uid);
        if (count != null && count.intValue() > 0) {
            throw new UEException("模板名称已存在！");
        }
        this.webTempMapper.insert(name, name_en, name_zh, uid);
    }

    public void update(HttpSession session, Integer id, String name, String name_en, String name_zh, Integer version) throws Exception {
        Integer uid = ((User) session.getAttribute("userInfo")).getId();
        Integer count = this.webTempMapper.getCountByName(name, id, uid);
        if (count != null && count.intValue() > 0) {
            throw new UEException("模板名称已存在！");
        }
        Integer vcount = Integer.valueOf(this.webTempMapper.update(id, name, name_en, name_zh, version, DataRule.getRuleWhere(session, "t_web_policies"), uid));
        if (vcount.intValue() == 0) {
            throw new UEException("数据已被修改或删除，请刷新页面或返回");
        }
    }

    public Map<String, Object> getWebTempById(Integer id) throws Exception {
        return this.webTempMapper.getWebTempById(id);
    }

    public List<Map<String, Object>> getPoliciesTree(HttpSession session, String treedata, String name, String cve, String cnnvd) throws Exception {
        List<Map<String, Object>> policies = this.webTempMapper.getPolicies(treedata, name, cve, cnnvd, DataRule.getRuleWhere(session, "t_policies"));
        if (StringUtils.isBlank(treedata)) {
            return policies;
        }
        List<String> poliArr = Arrays.asList(treedata.split("`"));
        for (Map<String, Object> policy : policies) {
            if (poliArr.contains(ObjectUtil.getString(policy.get("id"), ""))) {
                policy.put("checked", true);
            }
        }
        return policies;
    }

    public String certificateImp(File f, String type) throws Exception {
        String result = "";
        switch (type.hashCode()) {
            case 79096:
                if (type.equals("PEM")) {
                    result = FileUtils.readFileToString(f);
                    break;
                }
                break;
            case 79138:
                if (type.equals("PFX")) {
                    result = new BASE64Encoder().encode(FileUtils.readFileToByteArray(f));
                    break;
                }
                break;
        }
        if (f != null && f.exists()) {
            f.delete();
        }
        return result;
    }

    public List<Map<String, Object>> getWebTempName(HttpSession session) throws Exception {
        return this.webTempMapper.getWebTempName(DataRule.getRuleWhere(session, "t_web_policies"));
    }

    public List<Map<String, Object>> searchWebType() throws Exception {
        return this.webTempMapper.searchWebType();
    }

    public void restoreLevel() throws Exception {
        Map<String, Map<String, Object>> policies = PoliciesSingleton.getInstance().getPolicesConfig();
        for (Map.Entry<String, Map<String, Object>> e : policies.entrySet()) {
            Map<String, Object> policy = e.getValue();
            this.webTempMapper.restoreLevel(e.getKey(), ObjectUtil.getString(policy.get("level"), ""));
        }
    }
}
